#!/usr/bin/python3
# -*- coding: utf-8 -*-

__author__ = 'wenbo'

import sys
from PyQt5.QtGui import *
from PyQt5.QtCore import *

# 自定义Switch button
from PyQt5.QtWidgets import QWidget


class SwitchBtn(QWidget):
    checkedChanged = pyqtSignal(bool)
    def __init__(self,parent=None,initcheck=False,width=50,height=26):
        super(QWidget, self).__init__(parent)

        self.checked = initcheck
        self.bgColorOff = QColor(255, 255, 255)
        self.bgColorOn = QColor(0, 120, 215)

        self.sliderColorOff = QColor(204, 204, 204)
        self.sliderColorOn = QColor(255, 255, 255)

        self.borderColorOff = QColor(204, 204, 204)
        self.borderColorOn = QColor(255, 255, 255)

        self.textColorOff = QColor(143, 143, 143)
        self.textColorOn = QColor(255, 255, 255)

        #self.textOff = "OFF"
        #self.textOn = "ON"

        self.space = 2
        self.rectRadius = 5

        self.step = self.width() / 50
        if self.checked:
            self.endX = width - height

        else:
            self.endX = 0
        self.startX = self.endX

        self.timer = QTimer(self)
        self.timer.timeout.connect(self.updateValue)




        #self.setFont(QFont("Microsoft Yahei", 10))


    #
    # 函数：刷新按钮状态
    #
    def updateValue(self):
        if self.checked:
            if self.startX < self.endX:
                self.startX = self.startX + self.step
            else:
                self.startX = self.endX
                self.timer.stop()
        else:
            if self.startX  > self.endX:
                self.startX = self.startX - self.step
            else:
                self.startX = self.endX
                self.timer.stop()

        self.update()


    #
    # 函数：鼠标点击
    #
    def mousePressEvent(self,event):
        self.checked = not self.checked

        self.checkedChanged.emit(self.checked)



        self.step = self.width() / 50

        if self.checked:
            self.endX = self.width() - self.height()
        else:
            self.endX = 0
        self.timer.start(5)

    def paintEvent(self, evt):

            painter = QPainter(self)
            painter.setRenderHint(QPainter.Antialiasing)
            self.drawBg(evt, painter)
            self.drawSlider(evt, painter)
            self.drawText(evt, painter)


    def drawText(self, event, painter):
        painter.save()

        if self.checked:
            painter.setPen(self.textColorOn)
            #painter.drawText(0, 0, self.width() / 2 + self.space * 2, self.height(), Qt.AlignCenter, self.textOn)
        else:
            painter.setPen(self.textColorOff)
            #painter.drawText(self.width() / 2, 0,self.width() / 2 - self.space, self.height(), Qt.AlignCenter, self.textOff)

        painter.restore()


    def drawBg(self, event, painter):
        painter.save()


        if self.checked:
            painter.setBrush(self.bgColorOn)
            painter.setPen(self.borderColorOn)
        else:
            painter.setBrush(self.bgColorOff)
            painter.setPen(self.borderColorOff)

        rect = QRect(0, 0, self.width(), self.height())
        radius = rect.height() / 2
        circleWidth = rect.height()

        path = QPainterPath()
        path.moveTo(radius, rect.left())
        path.arcTo(QRectF(rect.left(), rect.top(), circleWidth, circleWidth), 90, 180)
        path.lineTo(rect.width() - radius, rect.height())
        path.arcTo(QRectF(rect.width() - rect.height(), rect.top(), circleWidth, circleWidth), 270, 180)
        path.lineTo(radius, rect.top())

        painter.drawPath(path)
        painter.restore()

    def drawSlider(self, event, painter):
        painter.save()
        painter.setPen(Qt.NoPen)

        if self.checked:
            painter.setBrush(self.sliderColorOn)

        else:
            painter.setBrush(self.sliderColorOff)


        rect = QRect(0, 0, self.width(), self.height())
        sliderWidth = rect.height() - self.space * 2
        sliderRect = QRect(self.startX + self.space, self.space, sliderWidth, sliderWidth)
        painter.drawEllipse(sliderRect)

        painter.restore()